package com.zhyc.module.app.mapper;

import java.util.List;

import com.zhyc.module.app.domain.AppErrorLog;
import org.apache.ibatis.annotations.Mapper;

/**
 * App错误日志Mapper接口
 * 
 * @author ruoyi
 * @date 2026-01-19
 */
@Mapper
public interface AppErrorLogMapper 
{
    /**
     * 查询App错误日志
     * 
     * @param id App错误日志主键
     * @return App错误日志
     */
    public AppErrorLog selectAppErrorLogById(Long id);

    /**
     * 查询App错误日志列表
     * 
     * @param appErrorLog App错误日志
     * @return App错误日志集合
     */
    public List<AppErrorLog> selectAppErrorLogList(AppErrorLog appErrorLog);

    /**
     * 新增App错误日志
     * 
     * @param appErrorLog App错误日志
     * @return 结果
     */
    public int insertAppErrorLog(AppErrorLog appErrorLog);

    /**
     * 修改App错误日志
     * 
     * @param appErrorLog App错误日志
     * @return 结果
     */
    public int updateAppErrorLog(AppErrorLog appErrorLog);

    /**
     * 删除App错误日志
     * 
     * @param id App错误日志主键
     * @return 结果
     */
    public int deleteAppErrorLogById(Long id);

    /**
     * 批量删除App错误日志
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppErrorLogByIds(Long[] ids);
}
